@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,9 +26,13 @@ Handles edit mode setting.
 from gi.repository import Gdk
 
 import copy
+import hashlib
+import os
+import shutil
 
 import appconsts
 import audiosync
+import callbackbridge
 import clipeffectseditor
 import clipenddragmode
 import compositeeditor
@@ -42,11 +46,12 @@ import edit
 import editorstate
 from editorstate import current_sequence
 from editorstate import PLAYER
+from editorstate import PROJECT
 from editorstate import timeline_visible
 from editorstate import EDIT_MODE
 import editorpersistance
 import gui
-import guicomponents
+import guipopoverclip
 import kftoolmode
 import medialog
 import modesetting
@@ -57,15 +62,16 @@ import syncsplitevent
 import tlinewidgets
 import trimmodes
 import updater
+import userfolders
 
 
 # functions are monkeypatched in at app.py 
-display_clip_menu_pop_up = None
-compositor_menu_item_activated = None
 
+#compositor_menu_item_activated = None
+#set_compositor_data = None
 
 # ----------------------------- module funcs
-def do_clip_insert(track, new_clip, tline_pos):
+def do_clip_insert(track, new_clip, tline_pos, use_clip_in=False):
     index = _get_insert_index(track, tline_pos)
 
     # Can't put audio media on video track 
@@ -76,18 +82,24 @@ def do_clip_insert(track, new_clip, tline_pos):
 
     movemodes.clear_selected_clips()
     
+    clip_in = new_clip.mark_in
+    clip_out = new_clip.mark_out
+    if use_clip_in == True:
+        clip_in = new_clip.clip_in
+        clip_out = new_clip.clip_out
+    
     # Do edit
     data = {"track":track,
             "clip":new_clip,
             "index":index,
-            "clip_in":new_clip.mark_in,
-            "clip_out":new_clip.mark_out}
+            "clip_in":clip_in,
+            "clip_out":clip_out}
     action = edit.insert_action(data)
-    action.do_edit()
+    _do_action_and_maybe_autosplit_action(action, new_clip, track)
     
     updater.display_tline_cut_frame(track, index)
 
-def do_multiple_clip_insert(track, clips, tline_pos):
+def do_multiple_clip_insert(track, clips, tline_pos, use_as_action_build_func_for_paste=False):
     index = _get_insert_index(track, tline_pos)
     
     # Can't put audio media on video track
@@ -95,7 +107,7 @@ def do_multiple_clip_insert(track, clips, tline_pos):
         if isinstance(new_clip, int):
             continue
         if ((new_clip.media_type == appconsts.AUDIO)
-           and (track.type == appconsts.VIDEO)):        
+           and (track.type == appconsts.VIDEO)):
             _display_no_audio_on_video_msg(track)
             return
 
@@ -106,6 +118,8 @@ def do_multiple_clip_insert(track, clips, tline_pos):
             "clips":clips,
             "index":index}
     action = edit.insert_multiple_action(data)
+    if use_as_action_build_func_for_paste == True:
+        return action
     action.do_edit()
 
     updater.display_tline_cut_frame(track, index)
@@ -113,12 +127,13 @@ def do_multiple_clip_insert(track, clips, tline_pos):
 def  _attempt_dnd_overwrite(track, clip, frame):
     # Can't put audio media on video track 
     if ((clip.media_type == appconsts.AUDIO)
-       and (track.type == appconsts.VIDEO)):        
+       and (track.type == appconsts.VIDEO)):
         return
 
     # Dropping on first available frame after last clip is append 
     # and is handled by insert code
     if track.get_length() == frame:
+        print("insert")
         return False
 
     # Clip dropped after last clip on track
@@ -134,7 +149,8 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                 "clip_in":clip.mark_in,
                 "clip_out":clip.mark_out}
         action = edit.dnd_after_track_end_action(data)
-        action.do_edit()
+        _do_action_and_maybe_autosplit_action(action, clip, track)
+
 
         updater.display_tline_cut_frame(track, index + 1)
         return True
@@ -163,7 +179,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                         "index":index,
                         "clip_in":clip.mark_in}
                 action = edit.dnd_on_blank_replace_action(data)
-                action.do_edit()
+                _do_action_and_maybe_autosplit_action(action, clip, track)
             else: # If dropped clip shorter then blank, replace start part of blank
                 data = {"track":track,
                         "clip":clip,
@@ -172,7 +188,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                         "clip_in":clip.mark_in,
                         "clip_out":clip.mark_out}
                 action = edit.dnd_on_blank_start_action(data)
-                action.do_edit()
+                _do_action_and_maybe_autosplit_action(action, clip, track)
 
             updater.display_tline_cut_frame(track, index)
             return True
@@ -188,7 +204,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                     "clip_in":clip.mark_in,
                     "clip_out":clip.mark_out}
             action = edit.dnd_on_blank_end_action(data)
-            action.do_edit()
+            _do_action_and_maybe_autosplit_action(action, clip, track)
         else: # Overwrite part of blank ei toimi
             data = {"track":track,
                     "clip":clip,
@@ -198,13 +214,32 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                     "clip_in":clip.mark_in,
                     "clip_out":clip.mark_out}
             action = edit.dnd_on_blank_middle_action(data)
-            action.do_edit()
+            _do_action_and_maybe_autosplit_action(action, clip, track)
             
         updater.display_tline_cut_frame(track, index + 1)
         return True
 
     return False # this won't be hit
+
+def _do_action_and_maybe_autosplit_action(action, clip, track):
     
+    if editorpersistance.prefs.sync_autosplit == appconsts.AUDIO_AUTO_SPLIT_ALL_TACKS:
+        auto_split = True
+    elif editorpersistance.prefs.sync_autosplit == appconsts.AUDIO_AUTO_SPLIT_V1_V2 and (track.id == current_sequence().first_video_index or track.id == current_sequence().first_video_index + 1):
+        auto_split = True
+    elif editorpersistance.prefs.sync_autosplit == appconsts.AUDIO_AUTO_SPLIT_V1 and track.id == current_sequence().first_video_index:
+        auto_split = True
+    else:
+        auto_split = False
+    
+    if track.type == appconsts.AUDIO or auto_split == False:
+        action.do_edit()
+    else:
+        split_action = lambda : syncsplitevent.get_synched_split_action_for_clip_and_track(clip, track)
+        edit_actions = [action, split_action]
+        action = edit.ConsolidatedEditAction(edit_actions)
+        action.do_consolidated_edit()
+
 def _get_insert_index(track, tline_pos):
     cut_frame = current_sequence().get_closest_cut_frame(track.id, tline_pos)
     index = current_sequence().get_clip_index(track, cut_frame)
@@ -274,7 +309,7 @@ def tline_canvas_mouse_pressed(event, frame):
                 PLAYER().seek_frame(frame)
             # Right mouse on timeline seeks frame
             else:
-                success = display_clip_menu_pop_up(event.y, event, frame)
+                success = callbackbridge.clipmenuaction_display_clip_menu(event.y, event, frame)
                 if not success:
                     PLAYER().seek_frame(frame)
         return
@@ -284,36 +319,25 @@ def tline_canvas_mouse_pressed(event, frame):
         modesetting.set_default_edit_mode()
         # This shouldn't happen unless for some reason mouse release didn't hit clipenddragmode listener.
         print("EDIT_MODE() == editorstate.CLIP_END_DRAG at mouse press!")
-
-    #  Check if match frame close is hit
-    if editorstate.current_is_move_mode() and timeline_visible():
-        if tlinewidgets.match_frame_close_hit(event.x, event.y) == True:
-            tlinewidgets.set_match_frame(-1, -1, True)
-            updater.repaint_tline()
-            return
-
+    
     #  Check if compositor is hit and if so, handle compositor editing.
     if editorstate.current_is_move_mode() and timeline_visible():
         hit_compositor = tlinewidgets.compositor_hit(frame, event.x, event.y, current_sequence().compositors)
         if hit_compositor != None:
-            if editorstate.get_compositing_mode() == appconsts.COMPOSITING_MODE_STANDARD_AUTO_FOLLOW:
-                compositeeditor.set_compositor(hit_compositor)
-                compositormodes.set_compositor_selected(hit_compositor)
-                movemodes.clear_selected_clips()
-                editorstate.timeline_mouse_disabled = True
+            movemodes.clear_selected_clips()
+            if event.button == 1 or (event.button == 3 and event.get_state() & Gdk.ModifierType.CONTROL_MASK):
+                compositormodes.set_compositor_mode(hit_compositor)
+                mode_funcs = EDIT_MODE_FUNCS[editorstate.COMPOSITOR_EDIT]
+                press_func = mode_funcs[TL_MOUSE_PRESS]
+                press_func(event, frame)
                 return
-            elif editorstate.auto_follow_active() == False or hit_compositor.obey_autofollow == False:
-                movemodes.clear_selected_clips()
-                if event.button == 1 or (event.button == 3 and event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-                    compositormodes.set_compositor_mode(hit_compositor)
-                    mode_funcs = EDIT_MODE_FUNCS[editorstate.COMPOSITOR_EDIT]
-                    press_func = mode_funcs[TL_MOUSE_PRESS]
-                    press_func(event, frame)
-                    return
             if event.button == 3:
                 compositormodes.set_compositor_selected(hit_compositor)
-                guicomponents.display_compositor_popup_menu(event, hit_compositor,
-                                                            compositor_menu_item_activated)
+                callbackbridge.clipmenuaction_set_compositor_data(hit_compositor)
+                guipopoverclip.compositor_popover_menu_show(gui.tline_canvas.widget,
+                                                            event.x, event.y, 
+                                                            hit_compositor, 
+                                                            callbackbridge.clipmenuaction_compositor_menu_item_activated)
                 return
             elif event.button == 2:
                 updater.zoom_project_length()
@@ -337,7 +361,7 @@ def tline_canvas_mouse_pressed(event, frame):
     if (event.button == 3 and EDIT_MODE() != editorstate.CLIP_END_DRAG and EDIT_MODE() != editorstate.KF_TOOL):
         if ((not editorstate.current_is_active_trim_mode()) and timeline_visible()):
             if not(event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-                success = display_clip_menu_pop_up(event.y, event, frame)
+                success = callbackbridge.clipmenuaction_display_clip_menu(event.y, event, frame)
                 if not success:
                     PLAYER().seek_frame(frame)
         else:
@@ -360,8 +384,8 @@ def tline_canvas_mouse_pressed(event, frame):
             pointer_context = appconsts.POINTER_CONTEXT_TRIM_LEFT	
         else:	
             pointer_context = appconsts.POINTER_CONTEXT_TRIM_RIGHT	
-        gui.editor_window.set_tline_cursor_to_context(pointer_context)	
-        gui.editor_window.set_tool_selector_to_mode()	
+        gui.editor_window.tline_cursor_manager.set_tline_cursor_to_context(pointer_context)	
+        gui.editor_window.tline_cursor_manager.set_tool_selector_to_mode()	
         if not editorpersistance.prefs.quick_enter_trims:	
             editorstate.timeline_mouse_disabled = True	
         else:	
@@ -402,10 +426,10 @@ def tline_canvas_mouse_released(x, y, frame, button, state):
     """
     Mouse event callback from timeline canvas widget
     """
-    gui.editor_window.set_cursor_to_mode() # we need this for box move at least, probably trims too
+    gui.editor_window.tline_cursor_manager.set_cursor_to_mode() # we need this for box move at least, probably trims too
      
     if editorstate.timeline_mouse_disabled == True:
-        gui.editor_window.set_cursor_to_mode() # we only need this update when mode change (to active trim mode) disables mouse, so we'll only do this then
+        gui.editor_window.tline_cursor_manager.set_cursor_to_mode() # we only need this update when mode change (to active trim mode) disables mouse, so we'll only do this then
         tlinewidgets.trim_mode_in_non_active_state = False # we only need this update when mode change (to active trim mode) disables mouse, so we'll only do this then
         gui.tline_canvas.widget.queue_draw()
         editorstate.timeline_mouse_disabled = False
@@ -508,7 +532,7 @@ def tline_effect_drop(x, y):
     clipeffectseditor.set_filter_item_expanded(len(clip.filters) - 1)
     
 def tline_media_drop(drag_data, x, y, use_marks=False):
-    # drag_data not used unless we wich later to enable dropping multiple media items.
+    # drag_data not used unless we which later to enable dropping multiple media items.
     track = tlinewidgets.get_track(y)
     if track == None:
         return
@@ -533,24 +557,38 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
     # Create new clip.
     if media_file.type != appconsts.PATTERN_PRODUCER:
         if media_file.container_data == None:
-            # Standard clips
-            new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
+            if media_file.titler_data == None:
+                # Standard clips
+                new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
+            else:
+                # Title clips
+                # Create copy of graphic and titler data for clip so that all clips created 
+                # from the same media item can be edited independently.
+                md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest() + ".png"
+                clip_graphic_path = userfolders.get_render_dir() + md_str
+                shutil.copyfile(media_file.path, clip_graphic_path)
+                titler_data = copy.deepcopy(media_file.titler_data)
+
+                new_clip = current_sequence().create_file_producer_clip(clip_graphic_path, media_file.name, False, media_file.ttl)
+                new_clip.titler_data = titler_data
         else:
             # Container clips, create new container_data object and generate uuid for clip so it gets it own folder in.$XML_DATA/.../container_clips
             new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
             new_clip.container_data = copy.deepcopy(media_file.container_data)
             new_clip.container_data.generate_clip_id()
+            new_clip.link_seq_data = media_file.link_seq_data
     else:
         new_clip = current_sequence().create_pattern_producer(media_file)
-            
+
     # Set clip in and out
     if use_marks == False:
+        # This probably dead code, use_marks=False always?
         new_clip.mark_in = 0
         new_clip.mark_out = new_clip.get_length() - 1 # - 1 because out is mark_out inclusive
 
         if media_file.type == appconsts.IMAGE_SEQUENCE:
             new_clip.mark_out = media_file.length
-    else:    
+    else: 
         # Media types that do not have length determined by content.
         if new_clip.media_type == appconsts.IMAGE or new_clip.media_type == appconsts.PATTERN_PRODUCER:
 
@@ -582,6 +620,16 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
                 if media_file.type == appconsts.IMAGE_SEQUENCE:
                     new_clip.mark_out = media_file.length
 
+    # Images from media panel get bin default length.
+    use_clip_in = False
+    if dnd.drag_source != dnd.SOURCE_MONITOR_WIDGET and new_clip.media_type == appconsts.IMAGE:
+        default_grfx_length = PROJECT().get_current_bin_graphics_default_length()
+        in_fr = (new_clip.get_length() - 1) // 2 - (default_grfx_length // 2)
+        out_fr = in_fr + default_grfx_length - 1
+        new_clip.clip_in = in_fr
+        new_clip.clip_out = out_fr
+        use_clip_in = True
+        
     # Non-insert DND actions
     if editorpersistance.prefs.dnd_action == appconsts.DND_OVERWRITE_NON_V1:
         if track.id != current_sequence().first_video_track().id:
@@ -597,7 +645,7 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
             gui.media_list_view.clear_selection()
             return
             
-    do_clip_insert(track, new_clip, frame)
+    do_clip_insert(track, new_clip, frame, use_clip_in)
     gui.media_list_view.clear_selection()
                 
     maybe_autorender_plugin(new_clip)
