@@ -22,24 +22,20 @@
 Module contains the main editor window object and timeline cursor handling.
 """
 
-import cairo
-
 from gi.repository import Gtk
-from gi.repository import Gdk
 
-import app
+
 import appconsts
 import audiomonitoring
 import audiosync
 import batchrendering
-import boxmove
+import callbackbridge
 import clipeffectseditor
 import clipmenuaction
 import compositeeditor
 import containerclip
 import dialogs
 import dialogutils
-import diskcachemanagement
 import dnd
 import editevent
 import editorlayout
@@ -50,8 +46,8 @@ import glassbuttons
 import gmic
 import gui
 import guicomponents
-import guipopover
 import guiutils
+import gtkbuilder
 import jobs
 import keyevents
 import medialinker
@@ -76,7 +72,9 @@ import projectinfogui
 import proxyediting
 import scripttool
 import shortcuts
+import shortcutsdialog
 import singletracktransition
+import syncsplitevent
 import titler
 import tlineaction
 import tlinecursors
@@ -124,10 +122,10 @@ class EditorWindow:
             self.window2 = Gtk.Window(Gtk.WindowType.TOPLEVEL)
             self.window2.set_icon_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
             self.window2.set_border_width(5)
-            self.window2.connect("delete-event", lambda w, e:app.shutdown())
+            self.window2.connect("delete-event", lambda w, e:callbackbridge.app_shutdown())
 
         # To ask confirmation for shutdown
-        self.window.connect("delete-event", lambda w, e:app.shutdown())
+        self.window.connect("delete-event", lambda w, e:callbackbridge.app_shutdown())
 
         # Player consumer has to be stopped and started when window resized
         self.window.connect("window-state-event", lambda w, e:updater.refresh_player(e))
@@ -190,7 +188,7 @@ class EditorWindow:
                     self.window2.maximize()
                 else:
                     self.window2.resize(w, h)
-
+ 
             self.window2.move(x, y)
             self.window2.show_all()
 
@@ -207,7 +205,7 @@ class EditorWindow:
 
     def _get_app_pane(self): 
         # VPaned top row / timeline
-        self.app_v_paned = Gtk.VPaned()
+        self.app_v_paned = gtkbuilder.VPaned()
         self.app_v_paned.pack1(self.top_row_hbox, resize=False, shrink=False)
         self.app_v_paned.pack2(self.tline_pane, resize=True, shrink=False)
 
@@ -215,7 +213,8 @@ class EditorWindow:
         self.app_h_box = Gtk.HBox(False, 0)
         self.app_h_box.pack_start(self.left_column_frame, False, False, 0)
         self.app_h_box.pack_start(self.app_v_paned, True, True, 0)
-
+        self.app_h_box.pack_start(self.right_column_frame, False, False, 0)
+        
         # Menu box
         self.menubar.set_margin_bottom(4)
         self.menubar.set_name("lighter-bg-widget")
@@ -229,46 +228,16 @@ class EditorWindow:
 
         monitor_source_box = Gtk.HBox(False, 0)
         monitor_source_box.pack_start(Gtk.Label(), True, True, 0)
-        monitor_source_box.pack_start(self.monitor_tc_info.monitor_source, False, False, 0)
-        monitor_source_box.pack_start(self.monitor_tc_info.monitor_tc, False, False, 0)
+        monitor_desc_panel = projectinfogui.get_top_level_project_info_panel()
+        self.monitor_desc_label = projectinfogui.widgets.monitor_desc_label
+        monitor_source_box.pack_start(monitor_desc_panel, False, False, 0)
         monitor_source_box.pack_start(Gtk.Label(), True, True, 0)
 
-        fullscreen_icon = guiutils.get_cairo_image("fullscreen")
-        fullscreen_exit_icon = guiutils.get_cairo_image("fullscreen_exit")
-        if editorpersistance.prefs.double_track_hights == False:
-            self.fullscreen_press = guicomponents.PressLaunch(menuactions.toggle_fullscreen, fullscreen_icon, 20, 12)
-        else:
-            self.fullscreen_press = guicomponents.PressLaunch(menuactions.toggle_fullscreen, fullscreen_icon, 40, 24)
-            self.fullscreen_press.surface_x = 12
-            self.fullscreen_press.surface_y = 13
-
-        self.fullscreen_press.widget.set_margin_top(1)
-        self.fullscreen_press.widget.set_tooltip_text(_("Fullscreen - F11"))
-        # Used in menuactions.toggle_fullscreen to switch image
-        self.fullscreen_press.fullscreen_icon = fullscreen_icon
-        self.fullscreen_press.fullscreen_exit_icon = fullscreen_exit_icon
-
-        icon_2 = guiutils.get_cairo_image("layout")
-        if editorpersistance.prefs.double_track_hights == False:
-            layout_press = guicomponents.PressLaunchPopover(editorlayout.show_layout_press_menu, icon_2, 24, 12)
-        else:
-            layout_press = guicomponents.PressLaunchPopover(editorlayout.show_layout_press_menu, icon_2, 48, 24)
-            layout_press.surface_y = 13
-            
-        layout_press.widget.set_margin_top(1)
-        layout_press.widget.set_tooltip_text(_("Layouts"))
-        
-        tline_info_box = Gtk.HBox(False, 0)
-        if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
-            tline_info_box.pack_start(self.tools_buttons.widget, False, False, 0)
-            tline_info_box.pack_start(guiutils.pad_label(24,2), False, False, 0)
-            tline_info_box.pack_start(self.fullscreen_press.widget, False, False, 0)
-            if editorstate.SCREEN_WIDTH > 1678:
-                tline_info_box.pack_start(guiutils.pad_label(6,2), False, False, 0)
-                tline_info_box.pack_start(layout_press.widget, False, False, 0)
-                tline_info_box.pack_start(guiutils.pad_label(6,2), False, False, 0)
-            
+        tline_info_box = Gtk.HBox(False, 0)            
         tline_info_box.pack_start(Gtk.Label(), True, True, 0)
+        tline_info_box.pack_start(self.monitor_tc_info.monitor_source, False, False, 0)
+        tline_info_box.pack_start(self.monitor_tc_info.monitor_tc, False, False, 0)
+        tline_info_box.pack_start(guiutils.pad_label(12, 2), False, False, 0)
         tline_info_box.pack_start(self.monitor_tc_info.widget, False, False, 0)
         guiutils.set_margins(tline_info_box, 0, 0, 0, 10)
         
@@ -289,9 +258,7 @@ class EditorWindow:
             menu_vbox.pack_start(tline_info_box, True, True, 0)
             menu_vbox.override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
         else:
-            menubar_box.pack_start(self.tools_buttons.widget, False, False, 0)
             menubar_box.pack_start(guiutils.pad_label(8, 2), False, False, 0)
-            menubar_box.pack_start(self.fullscreen_press.widget, False, False, 0)
             
             self.top_row_window_2 = Gtk.HBox(False, 0)
             self.top_row_window_2.pack_start(monitor_source_box, False, False, 0)
@@ -353,7 +320,7 @@ class EditorWindow:
             self.mm_paned.add(media_panel)
 
         else:
-            self.mm_paned = Gtk.HPaned()
+            self.mm_paned = gtkbuilder.HPaned()
             guiutils.set_margins(self.bins_panel, 6, 6, 8, 0)
             self.mm_paned.pack1(self.bins_panel, resize=True, shrink=True)
             self.mm_paned.pack2(media_panel, resize=True, shrink=False)
@@ -481,12 +448,11 @@ class EditorWindow:
         # Project panel
         if editorlayout.top_level_project_panel() == True:
             # Project info
-            project_info_panel = projectinfogui.get_top_level_project_info_panel()
             top_project_vbox = Gtk.VBox()
-            top_project_vbox.pack_start(project_info_panel, False, False, 0)
             top_project_vbox.pack_start(self.bins_panel, True, True, 0)
             top_project_vbox.pack_start(seq_panel, True, True, 0)
-            self.top_project_panel = guiutils.set_margins(top_project_vbox, 0, 0, 0, 4)
+
+            self.top_project_panel = guiutils.set_margins(top_project_vbox, 4, 4, 0, 4)
             self.project_panel = None
         else:
             # Notebook project panel for smallest screens
@@ -499,8 +465,32 @@ class EditorWindow:
             project_vbox.pack_start(seq_panel, True, True, 0)
             self.project_panel = guiutils.set_margins(project_vbox, 0, 2, 6, 2)
             self.top_project_panel = None 
+
+        # Middlebar
+        # Fullscreen and layout buttons are created here but adda to middlebar in middlebar.py
+        fullscreen_icon = guiutils.get_cairo_image("fullscreen")
+        fullscreen_exit_icon = guiutils.get_cairo_image("fullscreen_exit")
+        self.fullscreen_press = guicomponents.PressLaunch(menuactions.toggle_fullscreen, fullscreen_icon, 20, 12)
+        self.fullscreen_press.widget.set_margin_top(1)
+        self.fullscreen_press.widget.set_tooltip_text(_("Fullscreen - F11"))
+        # Used in menuactions.toggle_fullscreen to switch image
+        self.fullscreen_press.fullscreen_icon = fullscreen_icon
+        self.fullscreen_press.fullscreen_exit_icon = fullscreen_exit_icon
+
+        icon_2 = guiutils.get_cairo_image("layout")
+        self.layout_press = guicomponents.PressLaunchPopover(editorlayout.show_layout_press_menu, icon_2, 24, 12)
+        self.layout_press.widget.set_margin_top(1)
+        self.layout_press.widget.set_tooltip_text(_("Layouts"))
         
-        # Position bar and decorative frame  for it
+        self.edit_buttons_row = self._get_edit_buttons_row()
+
+        self.edit_buttons_frame = Gtk.Frame()
+        self.edit_buttons_frame.add(self.edit_buttons_row)
+        guiutils.set_margins(self.edit_buttons_frame, 1, 0, 0, 0)
+
+        self.edit_buttons_frame.override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
+        
+        # Position bar and decorative frame for it
         self.pos_bar = PositionBar()
         pos_bar_frame = Gtk.HBox()
         pos_bar_frame.add(self.pos_bar.widget)
@@ -513,19 +503,8 @@ class EditorWindow:
         self._create_monitor_buttons()
         self._create_monitor_row_widgets()
 
-        self.player_buttons = glassbuttons.PlayerButtons()
-        if (editorpersistance.prefs.play_pause == True):
-            if (editorpersistance.prefs.timeline_start_end is True):
-            # ------------------------------ timeline_start_end_button
-                tooltips = [_("Start - Home key"), _("End - End key"),_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play/Pause- Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-            else:
-                tooltips = [_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play/Pause - Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-        else:
-            if (editorpersistance.prefs.timeline_start_end is True):
-                tooltips = [_("Start - Home key"), _("End - End key"),_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play - Space"), _("Stop - Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-            else:
-                tooltips = [_("Prev Frame - Arrow Left"), _("Next Frame - Arrow Right"), _("Play - Space"), _("Stop - Space"), _("Mark In - I"), _("Mark Out - O"), _("Clear Marks"), _("To Mark In"), _("To Mark Out")]
-            # ------------------------------End of timeline_start_end_button
+        self.player_buttons = glassbuttons.PlayerButtonsCompact()
+        tooltips = [_("Prev Frame - Arrow Left"),  _("Play/Pause - Space"), _("Next Frame - Arrow Right")]
         tooltip_runner = glassbuttons.TooltipRunner(self.player_buttons, tooltips)
         if editorpersistance.prefs.buttons_style == 2: # NO_DECORATIONS
             self.player_buttons.no_decorations = True
@@ -534,17 +513,37 @@ class EditorWindow:
         self.view_mode_select.widget.set_margin_end(10)
         self.trim_view_select = guicomponents.get_trim_view_select_launcher(monitorevent.trim_view_menu_launched)
 
+        callbacks = [monitorevent.mark_in_pressed,
+                     monitorevent.mark_out_pressed,
+                     monitorevent.marks_clear_pressed]
+        markbuttons = glassbuttons.MarkButtons(callbacks)
+        markbuttons.widget.set_margin_right(12)
+        mbtooltips = [_("Mark In - I"),  _("Mark Out - O"), _("Clear Marks - Alt + K")]
+        tooltip_runner = glassbuttons.TooltipRunner(markbuttons, mbtooltips)
+        
         player_buttons_row = Gtk.HBox(False, 0)
         player_buttons_row.pack_start(self.monitor_switch.widget, False, False, 0)
         player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
         player_buttons_row.pack_start(self.player_buttons.widget, False, False, 0)
         player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
+        player_buttons_row.pack_start(markbuttons.widget, False, False, 0)
         player_buttons_row.pack_start(self.trim_view_select.widget, False, False, 0)
         player_buttons_row.pack_start(self.view_mode_select.widget, False, False, 0)
-        player_buttons_row.set_margin_top(4)
-        self.player_buttons_row = player_buttons_row
+        player_buttons_row.set_margin_top(8)
+        player_buttons_row.set_margin_bottom(6)
+        player_buttons_row.set_margin_left(12)
+        player_buttons_row.set_margin_right(12)
 
-        # Switch / pos bar row
+        player_buttons_row.set_name("player-bar")
+        gui.apply_widget_css(player_buttons_row, "player-bar", "player-bar-id.css")
+        
+        self.player_buttons_row = player_buttons_row
+        
+        tc_player_row = Gtk.HBox(False, 0)
+        tc_player_row.pack_start(self.big_TC, False, False, 0)
+        tc_player_row.pack_start(player_buttons_row, True, True, 0)
+
+        # pos bar row
         sw_pos_hbox = Gtk.HBox(False, 1)
         sw_pos_hbox.pack_start(pos_bar_frame, True, True, 0)
         
@@ -558,23 +557,14 @@ class EditorWindow:
         # Monitor
         monitor_vbox = Gtk.VBox(False, 0)
         monitor_vbox.pack_start(monitor_widget.widget, True, True, 0)
-        monitor_vbox.pack_start(player_buttons_row, False, True, 0)
+        monitor_vbox.pack_start(tc_player_row, False, True, 0)
         monitor_vbox.pack_start(sw_pos_hbox, False, True, 0)
         monitor_align = guiutils.set_margins(monitor_vbox, 0, 0, 0, 0)
 
         self.monitor_frame = Gtk.Frame()
         self.monitor_frame.add(monitor_align)
         self.monitor_frame.set_size_request(MONITOR_AREA_WIDTH, appconsts.TOP_ROW_HEIGHT)
-        
-        # Middlebar
-        self.edit_buttons_row = self._get_edit_buttons_row()
 
-        self.edit_buttons_frame = Gtk.Frame()
-        self.edit_buttons_frame.add(self.edit_buttons_row)
-        guiutils.set_margins(self.edit_buttons_frame, 1, 0, 0, 0)
-
-        self.edit_buttons_frame.override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
-            
     def _init_tline(self):
         self.tline_scale = tlinewidgets.TimeLineFrameScale(modesetting.set_default_edit_mode,
                                                            updater.mouse_scroll_zoom)
@@ -588,11 +578,8 @@ class EditorWindow:
         info_h.pack_start(Gtk.Label(), True, True, 0)
         # Aug-2019 - SvdB - BB - Height doesn't need to be doubled. 1.4x is nicer
         size_adj = 1
-        size_x = tlinewidgets.COLUMN_WIDTH - 22 - 22 - 22
+        size_x = tlinewidgets.COLUMN_WIDTH - 22 - 22 - 22 - 22
         size_y = tlinewidgets.SCALE_HEIGHT
-        if editorpersistance.prefs.double_track_hights:
-            size_adj = 1.4
-            size_x = tlinewidgets.COLUMN_WIDTH - (66*size_adj)
 
         info_h.set_size_request(size_x, size_y)
 
@@ -606,9 +593,13 @@ class EditorWindow:
         levels_launcher_surface = guiutils.get_cairo_image("audio_levels_menu_launch")
         levels_launcher = guicomponents.PressLaunchPopover(trackaction.tline_properties_menu_launch_pressed, levels_launcher_surface, 22*size_adj, 22*size_adj)
 
+        sync_launcher_surface = guiutils.get_cairo_image("sync_menu_launch")
+        sync_launcher = guicomponents.PressLaunchPopover(syncsplitevent.sync_menu_launch_pressed, sync_launcher_surface, 22*size_adj, 22*size_adj)
+
         # Timeline top row
         tline_hbox_1 = Gtk.HBox()
         tline_hbox_1.pack_start(info_h, False, False, 0)
+        tline_hbox_1.pack_start(sync_launcher.widget, False, False, 0)
         tline_hbox_1.pack_start(levels_launcher.widget, False, False, 0)
         tline_hbox_1.pack_start(tracks_launcher.widget, False, False, 0)
         tline_hbox_1.pack_start(markers_launcher.widget, False, False, 0)
@@ -758,7 +749,7 @@ class EditorWindow:
 
 
         # ---------------------------------------------------------------- LEFT  COLUMN
-        self.left_column_panel, widget_is_notebook  = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_LEFT_COLUMN)
+        self.left_column_panel, widget_is_notebook = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_LEFT_COLUMN)
         if self.left_column_panel != None:
             self.left_column_frame = guiutils.get_panel_etched_frame(self.left_column_panel)
             guiutils.set_margins(self.left_column_frame, 0, 0, 0, 1)
@@ -766,8 +757,17 @@ class EditorWindow:
         else:
             self.left_column_frame = guiutils.get_empty_panel_etched_frame() # to be filled later if panels are added into this position.
 
+        # ---------------------------------------------------------------- RIGHT COLUMN
+        self.right_column_panel, widget_is_notebook = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_RIGHT_COLUMN)
+        if self.right_column_panel != None:
+            self.right_column_frame = guiutils.get_panel_etched_frame(self.right_column_panel)
+            guiutils.set_margins(self.right_column_frame, 0, 0, 0, 1)
+
+        else:
+            self.right_column_frame = guiutils.get_empty_panel_etched_frame() # to be filled later if panels are added into this position.
+            
         # Top row paned
-        self.top_paned = Gtk.HPaned()
+        self.top_paned = gtkbuilder.HPaned()
         if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
             self.top_paned.pack1(self.notebook_frame , resize=True, shrink=False)
             self.top_paned.pack2(self.monitor_frame, resize=True, shrink=False)
@@ -807,7 +807,7 @@ class EditorWindow:
             ('ExportScreenshot', None, _('Current Frame'), None, None, lambda a:exporting.screenshot_export()),
             ('ExportToArdour', None, _('Current Sequence Audio As Ardour Session'), None, None, lambda a:exporting.ardour_export()),
             ('Close', None, _('_Close'), None, None, lambda a:projectaction.close_project()),
-            ('Quit', None, _('_Quit'), '<control>Q', None, lambda a:app.shutdown()),
+            ('Quit', None, _('_Quit'), '<control>Q', None, lambda a:callbackbridge.app_shutdown()),
             ('EditMenu', None, _('_Edit')),
             ('Undo', None, _('_Undo'), '<control>Z', None, undo.do_undo_and_repaint),
             ('Redo', None, _('_Redo'), '<control>Y', None, undo.do_redo_and_repaint),
@@ -822,6 +822,7 @@ class EditorWindow:
             ('RangeOverWriteClip', None, _('Range Overwrite'), None, None, lambda a:tlineaction.range_overwrite_pressed()),
             ('CutClip', None, _('Cut Clip At Playhead'), None, None, lambda a:tlineaction.cut_pressed()),
             ('SequenceSplit', None, _('Split to new Sequence at Playhead Position'), None, None, lambda a:tlineaction.sequence_split_pressed()),
+            ('SequenceDuplicate', None, _('Duplicate Sequence'), None, None, lambda a:projectaction.duplicate_sequence()),
             ('DeleteClip', None, _('Lift'), None, None, lambda a:tlineaction.lift_button_pressed()),
             ('SpliceOutClip', None, _('Splice Out'), None, None, lambda a:tlineaction.splice_out_button_pressed()),
             ('ResyncSelected', None, _('Resync Track'),  resync_shortcut, None, lambda a:tlineaction.resync_button_pressed()),
@@ -860,6 +861,7 @@ class EditorWindow:
             ('LoadMediaPluginScript', None, _('Load Generator Script...'), None, None,lambda w: containerclip.create_fluxity_media_item()),
             ('CreateSelectionCompound', None, _('From Selected Clips'), None, None, lambda a:projectaction.create_selection_compound_clip()),
             ('CreateSequenceCompound', None, _('From Current Sequence'), None, None, lambda a:projectaction.create_sequence_compound_clip()),
+            ('CreateSequenceLinkContainerItem', None, _("Add Sequence Link Container Clip..."), None, None, lambda a:projectaction.create_sequence_link_container()),
             ('CreateSequenceFreezeCompound', None, _('From Current Sequence With Freeze Frame at Playhead Position'), None, None, lambda a:projectaction.create_sequence_freeze_frame_compound_clip()),
             ('AudioSyncCompoundClip', None, _('Audio Sync Merge Clip From 2 Media Items '), None, None, lambda a:audiosync.create_audio_sync_compound_clip()),
             ('ImportProjectMedia', None, _('Import Media From Project...'), None, None, lambda a:projectaction.import_project_media()),
@@ -867,14 +869,13 @@ class EditorWindow:
             ('CreateGMicContainerItem', None, _("From G'Mic Script"), None, None, lambda a:containerclip.create_gmic_media_item()),
             ('CombineSequences', None, _('Import Another Sequence Into This Sequence...'), None, None, lambda a:projectaction.combine_sequences()),
             ('LogClipRange', None, _('Log Marked Clip Range'), '<control>L', None, lambda a:medialog.log_range_clicked()),
-            ('ViewProjectEvents', None, _('View Project Events...'), None, None, lambda a:projectaction.view_project_events()),
             ('RecreateMediaIcons', None, _('Recreate Media Icons...'), None, None, lambda a:menuactions.recreate_media_file_icons()),
+            ('ShowProjectInfo', None, _('Project Info and Data'), None, None, lambda a:projectaction.show_project_info()),
             ('RemoveUnusedMedia', None, _('Remove Unused Media...'), None, None, lambda a:projectaction.remove_unused_media()),
             ('ChangeProfile', None, _("Change Project Profile..."), None, None, lambda a: projectaction.change_project_profile()),
             ('ProxyManager', None, _('Proxy Manager'), None, None, lambda a:proxyediting.show_proxy_manager_dialog()),
             ('DataStoreManager', None, _('Data Store Manager'), None, None, lambda a:projectdatavaultgui.show_project_data_manager_window()),
             ('ProjectDataInfo', None, _('Project Data'), None, None, lambda a:projectdatavaultgui.show_current_project_data_store_info_window()),
-            ('ProjectInfo', None, _('Project Info'), None, None, lambda a:menuactions.show_project_info()),
             ('RenderMenu', None, _('Render')),
             ('AddToQueue', None, _('Add To Batch Render Queue...'), None, None, lambda a:projectaction.add_to_render_queue()),
             ('BatchRender', None, _('Batch Render Queue'), None, None, lambda a:batchrendering.launch_batch_rendering()),
@@ -890,7 +891,7 @@ class EditorWindow:
             ('QuickReference', None, _('Contents'), None, None, lambda a:menuactions.quick_reference()),
             ('QuickReferenceWeb', None, _('Contents Web'), None, None, lambda a:menuactions.quick_reference_web()),
             ('Environment', None, _('Runtime Environment'), None, None, lambda a:menuactions.environment()),
-            ('KeyboardShortcuts', None, _('Keyboard Shortcuts'), None, None, lambda a:dialogs.keyboard_shortcuts_dialog(self.window, workflow.get_tline_tool_working_set, menuactions.keyboard_shortcuts_callback, keyevents.change_single_shortcut, menuactions.keyboard_shortcuts_menu_item_selected_callback)),
+            ('KeyboardShortcuts', None, _('Keyboard Shortcuts'), None, None, lambda a:shortcutsdialog.keyboard_shortcuts_dialog(self.window, workflow.get_tline_tool_working_set, menuactions.keyboard_shortcuts_callback, keyevents.change_single_shortcut, menuactions.keyboard_shortcuts_menu_item_selected_callback)),
             ('About', None, _('About'), None, None, lambda a:menuactions.about()),
             ('TOOL_ACTION_KEY_1', None, None, '1', None, lambda a:_this_is_not_used()),
             ('TOOL_ACTION_KEY_2', None, None, '2', None, lambda a:_this_is_not_used()),
@@ -974,6 +975,7 @@ class EditorWindow:
                         <separator/>
                         <menuitem action='CreateGMicContainerItem'/>
                     </menu>
+                    <menuitem action='CreateSequenceLinkContainerItem'/>
                     <separator/>
                     <menuitem action='AddMediaFolder'/>
                     <menuitem action='ImportProjectMedia'/>
@@ -991,7 +993,7 @@ class EditorWindow:
                     <separator/>
                     <menuitem action='ChangeProfile'/>
                     <separator/>
-                    <menuitem action='ProjectDataInfo'/>
+                    <menuitem action='ShowProjectInfo'/>
                     <separator/>
                     <menuitem action='ProxyManager'/>
                 </menu>
@@ -1004,6 +1006,7 @@ class EditorWindow:
                     <separator/>
                     <menuitem action='CombineSequences'/>
                     <menuitem action='SequenceSplit'/>
+                    <menuitem action='SequenceDuplicate'/>
                     <separator/>
                     <menuitem action='AddVideoTrack'/>
                     <menuitem action='AddAudioTrack'/>
@@ -1230,15 +1233,6 @@ class EditorWindow:
             menu.append(new_item)
             new_item.show()
 
-    """
-    def hide_tline_render_strip(self):
-        guiutils.remove_children(self.tline_renderer_hbox)
-
-    def show_tline_render_strip(self):
-        self.tline_renderer_hbox.pack_start(self.pad_box, False, False, 0)
-        self.tline_renderer_hbox.pack_start(self.tline_render_strip.widget, True, True, 0)
-    """
-    
     def _change_windows_preference(self, widget, new_window_layout):
         if widget.get_active() == False:
             return
@@ -1299,6 +1293,8 @@ class EditorWindow:
     # ----------------------------------------------------------- GUI components monitor, middlebar.
     def _create_monitor_buttons(self):
         self.monitor_switch = guicomponents.MonitorSwitch(self._monitor_switch_handler)
+        self.monitor_switch.widget.set_margin_top(2)
+        self.monitor_switch.widget.set_margin_right(57)
 
     def _create_monitor_row_widgets(self):
         self.monitor_tc_info = guicomponents.MonitorMarksTCInfo()
@@ -1312,54 +1308,10 @@ class EditorWindow:
             updater.display_clip_in_monitor()
 
     def connect_player(self, mltplayer):
-        # Buttons
-        # NOTE: ORDER OF CALLBACKS IS THE SAME AS ORDER OF BUTTONS FROM LEFT TO RIGHT
-        # Jul-2016 - SvdB - For play/pause button
-        if editorpersistance.prefs.play_pause == False:
-            # ------------------------------timeline_start_end_button
-            if (editorpersistance.prefs.timeline_start_end is True):
-                pressed_callback_funcs = [monitorevent.start_pressed,  #  go to start
-                                          monitorevent.end_pressed,   #  go to  end
-                                          monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.stop_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
-            else:
-                pressed_callback_funcs = [monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.stop_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
-        else:
-            if (editorpersistance.prefs.timeline_start_end is True):
-                pressed_callback_funcs = [monitorevent.start_pressed,  #  go to start
-                                          monitorevent.end_pressed,   #  go to  end
-                                          monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
-            else:
-                pressed_callback_funcs = [monitorevent.prev_pressed,
-                                          monitorevent.next_pressed,
-                                          monitorevent.play_pressed,
-                                          monitorevent.mark_in_pressed,
-                                          monitorevent.mark_out_pressed,
-                                          monitorevent.marks_clear_pressed,
-                                          monitorevent.to_mark_in_pressed,
-                                          monitorevent.to_mark_out_pressed]
+
+        pressed_callback_funcs = [monitorevent.prev_pressed,
+                                  monitorevent.play_stop_pressed,
+                                  monitorevent.next_pressed]
 
         self.player_buttons.set_callbacks(pressed_callback_funcs)
 
@@ -1372,19 +1324,9 @@ class EditorWindow:
         middlebar.create_edit_buttons_row_buttons(self, tools_pixbufs)
 
         buttons_row = Gtk.HBox(False, 1)
-        if editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_COMPONENTS_CENTERED:
-            middlebar.fill_with_COMPONENTS_CENTERED_pattern(buttons_row, self)
-        elif editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_LEFT:
-            middlebar.fill_with_TC_LEFT_pattern(buttons_row, self)
-        else:
-            middlebar.fill_with_TC_MIDDLE_pattern(buttons_row, self)
+        middlebar.fill_with_TC_LEFT_pattern(buttons_row, self)
 
-        # Aug-2019 - SvdB - BB
         offset = 2
-        if editorpersistance.prefs.double_track_hights:
-           offset = 4
-           buttons_row.set_margin_bottom(offset)
-
         buttons_row.set_margin_top(offset)
         buttons_row.set_margin_start(offset)
         buttons_row.set_margin_end(offset)
@@ -1402,6 +1344,15 @@ class EditorWindow:
     def top_paned_resized(self, w, req):
         pass
 
+# testing
+def _apply_test_dimensions(window, test_index, scale):
+    dims = [(1920, 1200), (2048, 1152), (2048, 1536), (2560, 1440), (2560, 1600), (3440, 1440), (3840, 2160)]
+    w, h = dims[test_index]
+    print("unscaled", w, h)
+    w = int(w/scale)
+    h = int(h/scale)
+    print("scaled", w, h)
+    window.set_size_request(w, h)
 
 def _this_is_not_used():
     print("THIS WAS USED!!!!!")
