@@ -24,6 +24,8 @@ Module handles keyevents.
 
 from gi.repository import Gdk, Gtk
 
+import re
+
 import appconsts
 import clipeffectseditor
 import compositeeditor
@@ -42,12 +44,10 @@ import menuactions
 import modesetting
 import monitorevent
 import movemodes
-import multitrimmode
 import shortcuts
 import shortcutsquickeffects
-import re
+import syncsplitevent
 import render
-import rotomask
 import targetactions
 import tlineaction
 import tlinewidgets
@@ -136,7 +136,7 @@ def key_down(widget, event):
             # by stopping signal.
             gui.editor_window.window.emit_stop_by_name("key_press_event")
         return was_handled
-
+    
     # Insert shortcut keys need more focus then timeline shortcuts.
     # these may already have been handled in timeline focus events.
     was_handled = _handle_extended_monitor_focus_events(event)
@@ -163,7 +163,7 @@ def key_down(widget, event):
         _handle_clip_key_event(event)
         return True
         
-    #  Handle non-timeline delete .
+    #  Handle non-timeline delete.
     if event.keyval == Gdk.KEY_Delete:
         return _handle_delete()
 
@@ -194,12 +194,6 @@ def key_down(widget, event):
         menuactions.toggle_fullscreen()
         return True
 
-    #debug.test help 
-    #if event.keyval == Gdk.KEY_F12:
-    #    if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-    #        rotomask.show_rotomask()
-    #    return True
-
     # Key event was not handled here.
     return False
     
@@ -313,6 +307,23 @@ def _handle_tline_key_event(event):
     if action == 'trim_end':
         tlineaction.trim_end_pressed()
         return True
+    if action == 'monitor_show_video':
+        tlineaction.set_monitor_display_mode(appconsts.PROGRAM_OUT_MODE)
+        return True
+    if action == 'monitor_show_scope':
+        tlineaction.set_monitor_display_mode(appconsts.VECTORSCOPE_MODE)
+        return True
+    if action == 'monitor_show_rgb':
+        tlineaction.set_monitor_display_mode(appconsts.RGB_PARADE_MODE)
+        return True
+    if action == 'set_length':
+        tlineaction.set_length_from_keyevent()
+    if action == 'clear_sync_relation':
+        syncsplitevent.clear_sync_relation_from_keyevent()
+    if action == 'toggle_audio_mute':
+        tlineaction.mute_clip_from_keyevent()
+    if action == 'set_sync_relation':
+        syncsplitevent.init_select_master_clip_from_keyevent()
 
     # Key bindings for keyboard trimming
     if action == 'toggle_track_output':
@@ -330,7 +341,7 @@ def _handle_tline_key_event(event):
             trimmodes.enter_pressed()
             return True
 
-    if editorstate.EDIT_MODE() == editorstate.OVERWRITE_MOVE:
+    if editorstate.EDIT_MODE() == editorstate.OVERWRITE_MOVE: # is this what want, only in OVERWRITE_MOVE mode?
         if action == 'nudge_back':
             movemodes.nudge_selection(-1)
             return True
@@ -561,10 +572,10 @@ def _get_shortcut_action(event):
         if modifier == "":
             modifier = 'None'
         try:
-            action = _secondary_dict[''.join(sorted(re.sub('[\s]','',modifier.lower())))]
+            action = _secondary_dict[''.join(sorted(re.sub(r'[\s]','',modifier.lower())))]
         except:
             try:
-                action = _secondary_dict[''.join(sorted(re.sub('[\s]','','Any'.lower())))]
+                action = _secondary_dict[''.join(sorted(re.sub(r'[\s]','','Any'.lower())))]
             except:
                 action = 'None'
         return action
@@ -591,6 +602,15 @@ def _handle_configurable_global_events(event):
             return True
     if action == "move_media":
         gui.media_list_view.init_move()
+    if action == 'monitor_show_video':
+        tlineaction.set_monitor_display_mode(appconsts.PROGRAM_OUT_MODE)
+        return True
+    if action == 'monitor_show_scope':
+        tlineaction.set_monitor_display_mode(appconsts.VECTORSCOPE_MODE)
+        return True
+    if action == 'monitor_show_rgb':
+        tlineaction.set_monitor_display_mode(appconsts.RGB_PARADE_MODE)
+        return True
 
     return False
     
