@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,10 +22,10 @@
 Module has methods that build panels from widgets. Created panels
 are used to build gui at callsites.
 """
-from gi.repository import Gtk, Gdk
+from gi.repository import Gtk, Pango
 
 import appconsts
-import editorpersistance # Aug-2019 - SvdB - BB
+import editorpersistance
 from editorstate import current_sequence
 import gui
 import guicomponents
@@ -37,6 +37,7 @@ import renderconsumer
 import utils
 
 HALF_ROW_WIDTH = 160 # Size of half row when using two column row components created here
+ROW_WIDTH = 320
 EFFECT_PANEL_WIDTH_PAD = 20 # This is subtracted from notebGtk.Calendar ook width to get some component widths
 TC_LABEL_WIDTH = 80 # in, out and length timecodes in monitor area top row 
 
@@ -45,21 +46,16 @@ MEDIA_PANEL_MAX_ROWS = 8
 MEDIA_PANEL_DEFAULT_ROWS = 2
 
 
-def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, hamburger_launch_pressed, filtering_cb, media_pop_up_menu):   
-    # Aug-2019 - SvdB - BB
-    size_adj = 1
-    prefs = editorpersistance.prefs
-    if prefs.double_track_hights:
-        size_adj = 2
+def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, hamburger_launch_pressed, filtering_cb):   
+
     hamburger_launcher = guicomponents.HamburgerPressLaunch(hamburger_launch_pressed)
-    hamburger_launcher.connect_launched_menu(media_pop_up_menu)
+    hamburger_launcher.do_popover_callback = True
     guiutils.set_margins(hamburger_launcher.widget, 2, 0, 4, 12)
 
     columns_img = guiutils.get_cairo_image("columns")
-    columns_launcher = guicomponents.PressLaunch(col_changed_cb, columns_img, w=22*size_adj, h=22*size_adj)
+    columns_launcher = guicomponents.PressLaunchPopover(col_changed_cb, columns_img, w=22, h=22)
     columns_launcher.surface_y = 6
     columns_launcher.widget.set_tooltip_text(_("Number of Media File columns."))
-    columns_launcher.connect_launched_menu(guicomponents.column_count_menu)
     
     all_pixbuf = guiutils.get_cairo_image("show_all_files")
     audio_pixbuf = guiutils.get_cairo_image("show_audio_files")
@@ -69,11 +65,10 @@ def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, hambu
     pattern_pixbuf = guiutils.get_cairo_image("show_pattern_producers")
     unused_pixbuf = guiutils.get_cairo_image("show_unused_files")
 
-    files_filter_launcher = guicomponents.ImageMenuLaunch(filtering_cb, [all_pixbuf, video_pixbuf, audio_pixbuf, graphics_pixbuf, imgseq_pixbuf, pattern_pixbuf, unused_pixbuf], 24*size_adj, 22*size_adj)
+    files_filter_launcher = guicomponents.ImageMenuLaunchPopover(filtering_cb, [all_pixbuf, video_pixbuf, audio_pixbuf, graphics_pixbuf, imgseq_pixbuf, pattern_pixbuf, unused_pixbuf], 24, 22)
     files_filter_launcher.surface_x  = 3
     files_filter_launcher.surface_y  = 4
     files_filter_launcher.widget.set_tooltip_text(_("Visible Media File types."))
-    files_filter_launcher.connect_launched_menu(guicomponents.file_filter_menu)
     gui.media_view_filter_selector = files_filter_launcher
 
     bin_info = guicomponents.BinInfoPanel()
@@ -98,23 +93,22 @@ def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, hambu
 
     return (panel, bin_info)
 
-def get_bins_tree_panel(bin_list_view, callback, bins_popup_menu):   
+def get_bins_tree_panel(bin_list_view, callback):   
     panel = Gtk.VBox()
     panel.pack_start(bin_list_view, True, True, 0)
 
     hamburger = guicomponents.HamburgerPressLaunch(callback)
-    hamburger.connect_launched_menu(bins_popup_menu)
+    hamburger.do_popover_callback = True
     
-    return get_named_frame_with_hamburger(_("Bins"), panel, 0, 0, 0, _("A <b>Bin</b> is a named collection of media."), hamburger.widget)
+    return get_named_frame_with_hamburger(_("Bins"), panel, 0, 0, 0, 4, _("A <b>Bin</b> is a named collection of media."), hamburger.widget)
     
-def get_sequences_panel(sequence_list_view, callback, sequence_popup_menu):
+def get_sequences_panel(sequence_list_view, callback):
     panel = Gtk.VBox()
     panel.pack_start(sequence_list_view, True, True, 0)
 
     hamburger = guicomponents.HamburgerPressLaunch(callback)
-    hamburger.connect_launched_menu(sequence_popup_menu)
     
-    return get_named_frame_with_hamburger(_("Sequences"), panel, 0, 0, 0, _("A <b>Sequence</b> is the full contents of the timeline creating a program, a movie."), hamburger.widget)
+    return get_named_frame_with_hamburger(_("Sequences"), panel, 0, 0, 0, 4, _("A <b>Sequence</b> is the full contents of the timeline creating a program, a movie."), hamburger.widget)
 
 def _set_sensive_widgets(sensitive, list):
     for widget in list:
@@ -145,14 +139,15 @@ def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_pa
     
     return frame
 
-def get_named_frame_with_hamburger(name, widget, left_padding=12, right_padding=6, right_out_padding=4, tooltip_txt=None, hamburger_widget=None):
+def get_named_frame_with_hamburger(name, widget, left_padding=12, right_padding=6, right_out_padding=4, name_bottom_badding=2, tooltip_txt=None, hamburger_widget=None):
     """
     Gnome style named panel
     """
     if name != None:
         label = guiutils.bold_label(name)
         label.set_justify(Gtk.Justification.LEFT)
-        label.set_margin_left(4)
+        label.set_margin_start(4)
+        label.set_margin_bottom(name_bottom_badding)
         label_box = Gtk.HBox()
         label_box.pack_start(label, False, False, 0)
         label_box.pack_start(Gtk.Label(), True, True, 0)
@@ -196,20 +191,29 @@ def get_two_text_panel(primary_txt, secondary_txt):
     return align
 
 def get_file_properties_panel(data):
-    media_file, img, size, length, vcodec, acodec, channels, frequency, fps, match_profile_name, matches_current_profile = data
-    
-    row0 = get_two_column_box(get_bold_label(_("Name:")), Gtk.Label(label=media_file.name))
-    row00 = get_two_column_box(get_bold_label(_("Path:")), Gtk.Label(label=media_file.path))
-    row1 = get_two_column_box(get_bold_label(_("Image Size:")), Gtk.Label(label=size))
-    row111 = get_two_column_box(get_bold_label(_("Frames Per Second:")), Gtk.Label(label=fps))
-    row11 = get_two_column_box(get_bold_label(_("Playtime:")), Gtk.Label(label=length))
-    row2 = get_two_column_box(get_bold_label(_("Video Codec:")), Gtk.Label(label=vcodec))
-    row3 = get_two_column_box(get_bold_label(_("Audio Codec:")), Gtk.Label(label=acodec))
-    row4 = get_two_column_box(get_bold_label(_("Audio Channels:")), Gtk.Label(label=channels))
-    row5 = get_two_column_box(get_bold_label(_("Audio Sample Rate:")), Gtk.Label(label=frequency))
-    row6 = get_two_column_box(get_bold_label(_("Best Profile:")), Gtk.Label(label=match_profile_name))
-    row7 = get_two_column_box(get_bold_label(_("Matches Project Profile:")), Gtk.Label(label=matches_current_profile))
-    
+    media_file, img, size, length, vcodec, acodec, channels, frequency, \
+    fps, match_profile_name, matches_current_profile, pixel_format, colorspace = data
+
+    name_label = Gtk.Label(label=media_file.name)
+    name_label.set_max_width_chars(100)
+    name_label.set_ellipsize(Pango.EllipsizeMode.MIDDLE)
+    row0 = get_two_column_box_fixed(get_bold_label(_("Name:")), name_label)
+    path_label = Gtk.Label(label=media_file.path)
+    path_label.set_max_width_chars(100)
+    path_label.set_ellipsize(Pango.EllipsizeMode.MIDDLE)
+    row00 = get_two_column_box_fixed(get_bold_label(_("Path:")), path_label)
+    row1 = get_two_column_box_fixed(get_bold_label(_("Image Size:")), Gtk.Label(label=size))
+    row111 = get_two_column_box_fixed(get_bold_label(_("Frames Per Second:")), Gtk.Label(label=fps))
+    row11 = get_two_column_box_fixed(get_bold_label(_("Playtime:")), Gtk.Label(label=length))
+    row2 = get_two_column_box_fixed(get_bold_label(_("Video Codec:")), Gtk.Label(label=vcodec))
+    row3 = get_two_column_box_fixed(get_bold_label(_("Audio Codec:")), Gtk.Label(label=acodec))
+    row4 = get_two_column_box_fixed(get_bold_label(_("Audio Channels:")), Gtk.Label(label=channels))
+    row5 = get_two_column_box_fixed(get_bold_label(_("Audio Sample Rate:")), Gtk.Label(label=frequency))
+    row6 = get_two_column_box_fixed(get_bold_label(_("Best Profile:")), Gtk.Label(label=match_profile_name))
+    row7 = get_two_column_box_fixed(get_bold_label(_("Matches Project Profile:")), Gtk.Label(label=matches_current_profile))
+    row8 = get_two_column_box_fixed(get_bold_label(_("Colorspace:")), Gtk.Label(label=colorspace))
+    row9 = get_two_column_box_fixed(get_bold_label(_("Pixel Format:")), Gtk.Label(label=pixel_format))
+
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(img, False, False, 0)
     vbox.pack_start(guiutils.get_pad_label(12, 16), False, False, 0)
@@ -219,13 +223,14 @@ def get_file_properties_panel(data):
     vbox.pack_start(row111, False, False, 0)
     vbox.pack_start(row11, False, False, 0)
     vbox.pack_start(row2, False, False, 0)
+    vbox.pack_start(row9, False, False, 0)
+    vbox.pack_start(row8, False, False, 0)
     vbox.pack_start(row3, False, False, 0)
     vbox.pack_start(row4, False, False, 0)
     vbox.pack_start(row5, False, False, 0)
     vbox.pack_start(row6, False, False, 0)
     vbox.pack_start(row7, False, False, 0)
     vbox.pack_start(Gtk.Label(), True, True, 0)
-    
     return vbox
     
 def get_clip_properties_panel(data):
@@ -545,3 +550,7 @@ def get_left_justified_box(widgets):
 
 def get_two_column_box(widget1, widget2, left_width=HALF_ROW_WIDTH):
     return guiutils.get_two_column_box(widget1, widget2, left_width)
+
+def get_two_column_box_fixed(widget1, widget2, left_width=HALF_ROW_WIDTH, right_width=ROW_WIDTH, margin=12):
+    return guiutils.get_two_column_box_fixed(widget1, widget2, left_width, right_width, margin)
+    
\ No newline at end of file
