@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,11 +17,13 @@
     You should have received a copy of the GNU General Public License
     along with Flowblade Movie Editor. If not, see <http://www.gnu.org/licenses/>.
 """
+
+
 from gi.repository import GLib
 import os
-import threading
 
 import appconsts
+import projectdatavault
 
 _init_error = None
 
@@ -29,6 +31,7 @@ _xdg_config_dir = None
 _xdg_data_dir = None
 _xdg_cache_dir = None
 
+
 # --------------------------------------------------------- interface
 def init():
     global _init_error
@@ -65,9 +68,52 @@ def get_data_dir():
 def get_cache_dir():
     return _xdg_cache_dir + "/"
 
-def get_render_dir():
+def get_render_dir(force_legacy=False):
+    if projectdatavault.vault_data_exists_for_project() == False or force_legacy == True:
+        return get_data_dir() + appconsts.RENDERED_CLIPS_DIR + "/"
+    
+    return projectdatavault.get_render_folder() 
+
+def get_legacy_render_dir():
+    # For accessing legacy render data created prior to 2.12.
     return get_data_dir() + appconsts.RENDERED_CLIPS_DIR
 
+def get_container_clips_dir():
+    if projectdatavault.vault_data_exists_for_project() == False:
+        return get_data_dir() + appconsts.CONTAINER_CLIPS_DIR + "/"
+
+    return projectdatavault.get_containers_folder()
+    
+def get_container_clips_unrendered_dir():
+    if projectdatavault.vault_data_exists_for_project() == False:
+        return get_data_dir() + appconsts.CONTAINER_CLIPS_UNRENDERED + "/"
+
+    return projectdatavault.get_container_clips_unrendered_folder()
+    
+def get_proxies_dir():
+    if projectdatavault.vault_data_exists_for_project() == False:
+        return get_render_dir() + appconsts.PROXIES_DIR
+    
+    return projectdatavault.get_proxies_folder()
+
+def get_ingest_dir():
+    return projectdatavault.get_ingest_folder()
+    
+def get_audio_levels_dir():
+    if projectdatavault.vault_data_exists_for_project() == False:
+        return get_cache_dir() + appconsts.AUDIO_LEVELS_DIR 
+
+    return projectdatavault.get_audio_levels_folder()
+    
+def get_thumbnail_dir():
+    if projectdatavault.vault_data_exists_for_project() == False:
+        return get_cache_dir() + appconsts.THUMBNAILS_DIR + "/"
+ 
+    return projectdatavault.get_thumbnails_folder()
+
+def get_temp_render_dir():
+    return get_cache_dir() + appconsts.TEMP_RENDER_DIR 
+
 def get_hidden_screenshot_dir_path():
     return get_cache_dir() + "screenshot/"
 
@@ -93,18 +139,20 @@ def _maybe_create_xdg_dirs():
     # Data individual folders
     if not os.path.exists(get_data_dir() + appconsts.USER_PROFILES_DIR):
         os.mkdir(get_data_dir() + appconsts.USER_PROFILES_DIR)
+
     if not os.path.exists(get_render_dir()):
         os.mkdir(get_render_dir())
-    if not os.path.exists(get_data_dir() + appconsts.TLINE_RENDERS_DIR):
-        os.mkdir(get_data_dir() + appconsts.TLINE_RENDERS_DIR)
     if not os.path.exists(get_data_dir() + appconsts.CONTAINER_CLIPS_DIR):
         os.mkdir(get_data_dir() + appconsts.CONTAINER_CLIPS_DIR)
     if not os.path.exists(get_data_dir() + appconsts.CONTAINER_CLIPS_UNRENDERED):
         os.mkdir(get_data_dir() + appconsts.CONTAINER_CLIPS_UNRENDERED)
     if not os.path.exists(get_render_dir() +  "/" + appconsts.PROXIES_DIR):
         os.mkdir(get_render_dir() +  "/" + appconsts.PROXIES_DIR)
+
     if not os.path.exists(get_data_dir()  +  "/" + appconsts.USER_SHORTCUTS_DIR):
         os.mkdir(get_data_dir()  +  "/" + appconsts.USER_SHORTCUTS_DIR)
+    if not os.path.exists(get_data_dir()  +  "/" + appconsts.USER_USBHID_DIR):
+        os.mkdir(get_data_dir()  +  "/" + appconsts.USER_USBHID_DIR)
 
     #----------------- CACHE
     # Data that can be regerated by app or is transient
@@ -119,10 +167,9 @@ def _maybe_create_xdg_dirs():
         os.mkdir(get_cache_dir() + appconsts.THUMBNAILS_DIR)
     if not os.path.exists(get_cache_dir() + appconsts.GMIC_DIR):
         os.mkdir(get_cache_dir() + appconsts.GMIC_DIR)
-    if not os.path.exists(get_cache_dir() + appconsts.MATCH_FRAME_DIR):
-        os.mkdir(get_cache_dir() + appconsts.MATCH_FRAME_DIR)
     if not os.path.exists(get_cache_dir() + appconsts.AUDIO_LEVELS_DIR):
         os.mkdir(get_cache_dir() + appconsts.AUDIO_LEVELS_DIR)
+
     if not os.path.exists(get_cache_dir() + appconsts.TRIM_VIEW_DIR):
         os.mkdir(get_cache_dir() + appconsts.TRIM_VIEW_DIR)
     if not os.path.exists(get_cache_dir() + appconsts.BATCH_DIR):
@@ -131,3 +178,5 @@ def _maybe_create_xdg_dirs():
         os.mkdir(get_hidden_screenshot_dir_path())
     if not os.path.exists(get_cache_dir() + appconsts.SCRIP_TOOL_DIR):
         os.mkdir(get_cache_dir() + appconsts.SCRIP_TOOL_DIR)
+    if not os.path.exists(get_temp_render_dir()):
+        os.mkdir(get_temp_render_dir())
